@@ -1,5 +1,6 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 use strict;
+use warnings;
 use Games::Jumble;
 
 my $jumble = Games::Jumble->new;
